# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Perl and RPM versioning incompatibility
%global cpanversion 1.92
%global rpm_version 1.92

Name:		perl-BDB
Version:	%{rpm_version}
Release:	23.%{__distinit}%{__distvers}
Summary:	Asynchronous Berkeley DB access
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/BDB
Source0:	https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/BDB-%{cpanversion}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	libdb-devel >= 4.3
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(common::sense)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(XSLoader)
# Test Suite
# (no additional dependencies)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(XSLoader)
%if "%{rpm_version}" != "%{cpanversion}"
Provides:	perl(BDB) = %{rpm_version}
%endif

# Avoid provides for private shared objects
%{?perl_default_filter}

%description
Asynchronous Berkeley DB access.

%prep
%setup -q -n BDB-%{cpanversion}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license COPYING
%doc Changes README
%{perl_vendorarch}/auto/BDB/
%{perl_vendorarch}/BDB.pm
%{_mandir}/man3/BDB.3*

%changelog
* Fri May  3 2024 Paul Howarth <paul@city-fan.org> - 1.92-23
- Avoid use of %%{rpmversion} macro, now an rpm built-in

* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 1.92-20
- Perl 5.38 rebuild

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 1.92-17
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 1.92-13
- Perl 5.34 rebuild

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 1.92-11
- Perl 5.32 rebuild

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 1.92-7
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.92-4
- Perl 5.28 rebuild

* Fri Jan 19 2018 Paul Howarth <paul@city-fan.org> - 1.92-1
- Update to 1.92
  - Further USE_SOCKETS_AS_HANDLES fixes
  - New requests: db_env_lsn_reset, db_env_fileid_reset

* Tue Aug  8 2017 Paul Howarth <paul@city-fan.org> - 1.91-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Wed Jun 14 2017 Paul Howarth <paul@city-fan.org> - 1.91-7
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Thu Aug  4 2016 Paul Howarth <paul@city-fan.org> - 1.91-5
- Classify buildreqs by usage
- Simplify find commands using -empty and -delete

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 1.91-2
- Use %%license where possible

* Fri Apr 11 2014 Paul Howarth <paul@city-fan.org> - 1.91-1
- Update to 1.91
  - perl5porters broke Async::Interrupt, BDB, EV, IO::AIO and OpenCL without
    warning by switching the meaning of USE_SOCKETS_AS_HANDLES in 5.18
  - Make sure DBD.pm is installed to the correct directory
  - Support up to bdb 6.0
  - (xthread) Work around compile time bugs in ptw32
- Drop %%defattr, redundant since rpm 4.4

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 1.90-5
- Perl 5.18 rebuild

* Fri Jun 15 2012 Paul Howarth <paul@city-fan.org> - 1.90-3
- Perl 5.16 rebuild

* Thu Jun 14 2012 Paul Howarth <paul@city-fan.org> - 1.90-2
- BR: perl(base) and perl(Exporter)
- Don't need to remove empty directories from the buildroot

* Mon Dec 26 2011 Paul Howarth <paul@city-fan.org> - 1.90-1
- Update to 1.9
  - Update for libdb 5.2 (to make it compile only)
- Drop patch for libdb 5.2 support, no longer needed
- Work around versioning differences between perl and rpm

* Fri Jul 29 2011 Paul Howarth <paul@city-fan.org> - 1.89-1
- Update to 1.89
  - Make it compile and test successfully with libdb 5.1, but do not add any
    new symbols or functionality
- Build with libdb rather than db4 from Fedora 14/RHEL 7
- Add patch for libdb 5.2 support (CPAN RT#69881)

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 1.88-4
- Rebuild for perl 5.14.1 in Rawhide
- Use DESTDIR rather than PERL_INSTALL_ROOT
- Use %%{_fixperms} macro rather than our own %%{__chmod} incantation
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jan 21 2011 Paul Howarth <paul@city-fan.org> - 1.88-3
- Import from Fedora

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.88-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Sun Aug 22 2010 Nicolas Chauvet <kwizart@gmail.com> - 1.88-1
- Update to 1.88

* Thu Apr 29 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.87-2
- Mass rebuild with perl-5.12.0

* Tue Jan 19 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 1.87-1
- Update to 1.87
- Drop patch BDB-1.86-db_48

* Sun Dec 13 2009 Nicolas Chauvet <kwizart@fedoraproject.org> - 1.86-3
- Drop Patch0

* Tue Dec 8 2009 Nicolas Chauvet <kwizart@fedoraproject.org> - 1.86-2
- Patch to force db 4.8.

* Mon Dec 7 2009 Nicolas Chauvet <kwizart@fedoraproject.org> - 1.86-1
- Update to 1.86

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.84-2
- rebuild against perl 5.10.1

* Mon Aug 31 2009 kwizart < kwizart at gmail.com > - 1.84-1
- Update to 1.84
- Add Patch to get rid of common::sense

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.83-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb  3 2009 kwizart < kwizart at gmail.com > - 1.83-1
- Update to 1.83

* Wed Jan  7 2009 kwizart < kwizart at gmail.com > - 1.82-1
- Update to 1.82

* Fri Nov 28 2008 kwizart < kwizart at gmail.com > - 1.81-1
- Update to 1.81

* Thu Jul 17 2008 kwizart < kwizart at gmail.com > - 1.7-1
- Update to 1.7

* Tue May 27 2008 kwizart < kwizart at gmail.com > - 1.5-1
- Update to 1.5

* Wed Apr 30 2008 kwizart < kwizart at gmail.com > - 1.45-1
- Initial package for Fedora
